==> trade-center-api-2.3.52-1-sources.jar: cn/com/duiba/order/center/api/paramquery/OrdersWaitQuery.java <==
package cn.com.duiba.order.center.api.paramquery;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by sunyan on 2017/10/10.
 */
public class OrdersWaitQuery  implements Serializable {
    private static final long serialVersionUID = 2462787269261564747L;
    private Long appId;
    private String itemTitle;
    private String receiverTel;
    private Long consumerId;
    private  String orderNum;
    private Date startDate;
    private Date endDate;
    private Long maxId;
    private String isDevOrder;
    private String isDuibaOrder;
    private Integer offset;
    private Integer max;
    private Integer start;
    private Integer pageSize;
    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getItemTitle() {
        return itemTitle;
    }

    public void setItemTitle(String itemTitle) {
        this.itemTitle = itemTitle;
    }

    public String getReceiverTel() {
        return receiverTel;
    }

    public void setReceiverTel(String receiverTel) {
        this.receiverTel = receiverTel;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public String getOrderNum() {
        return orderNum;
    }

    public void setOrderNum(String orderNum) {
        this.orderNum = orderNum;
    }

    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }

    public Long getMaxId() {
        return maxId;
    }

    public void setMaxId(Long maxId) {
        this.maxId = maxId;
    }

    public String getIsDevOrder() {
        return isDevOrder;
    }

    public void setIsDevOrder(String isDevOrder) {
        this.isDevOrder = isDevOrder;
    }

    public String getIsDuibaOrder() {
        return isDuibaOrder;
    }

    public void setIsDuibaOrder(String isDuibaOrder) {
        this.isDuibaOrder = isDuibaOrder;
    }

    public Integer getOffset() {
        return offset;
    }

    public void setOffset(Integer offset) {
        this.offset = offset;
    }

    public Integer getMax() {
        return max;
    }

    public void setMax(Integer max) {
        this.max = max;
    }

    public Integer getStart() {
        return start;
    }

    public void setStart(Integer start) {
        this.start = start;
    }

    public Integer getPageSize() {
        return pageSize;
    }

    public void setPageSize(Integer pageSize) {
        this.pageSize = pageSize;
    }
}

==> trade-center-api-3.0.2-sources.jar: cn/com/duiba/order/center/api/paramquery/OrdersWaitQuery.java <==
package cn.com.duiba.order.center.api.paramquery;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by sunyan on 2017/10/10.
 */
public class OrdersWaitQuery  implements Serializable {
    private static final long serialVersionUID = 2462787269261564747L;
    private Long appId;
    private String itemTitle;
    private String receiverTel;
    private Long consumerId;
    private  String orderNum;
    private Date startDate;
    private Date endDate;
    private Long maxId;
    private String isDevOrder;
    private String isDuibaOrder;
    /**
     * 供应商角色绑定的供应商id
     */
    private Long developerSupplierId;
    private Integer offset;
    private Integer max;
    private Integer start;
    private Integer pageSize;
    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getItemTitle() {
        return itemTitle;
    }

    public void setItemTitle(String itemTitle) {
        this.itemTitle = itemTitle;
    }

    public String getReceiverTel() {
        return receiverTel;
    }

    public void setReceiverTel(String receiverTel) {
        this.receiverTel = receiverTel;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public String getOrderNum() {
        return orderNum;
    }

    public void setOrderNum(String orderNum) {
        this.orderNum = orderNum;
    }

    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }

    public Long getMaxId() {
        return maxId;
    }

    public void setMaxId(Long maxId) {
        this.maxId = maxId;
    }

    public String getIsDevOrder() {
        return isDevOrder;
    }

    public void setIsDevOrder(String isDevOrder) {
        this.isDevOrder = isDevOrder;
    }

    public String getIsDuibaOrder() {
        return isDuibaOrder;
    }

    public void setIsDuibaOrder(String isDuibaOrder) {
        this.isDuibaOrder = isDuibaOrder;
    }

    public Long getDeveloperSupplierId() {
        return developerSupplierId;
    }

    public void setDeveloperSupplierId(Long developerSupplierId) {
        this.developerSupplierId = developerSupplierId;
    }

    public Integer getOffset() {
        return offset;
    }

    public void setOffset(Integer offset) {
        this.offset = offset;
    }

    public Integer getMax() {
        return max;
    }

    public void setMax(Integer max) {
        this.max = max;
    }

    public Integer getStart() {
        return start;
    }

    public void setStart(Integer start) {
        this.start = start;
    }

    public Integer getPageSize() {
        return pageSize;
    }

    public void setPageSize(Integer pageSize) {
        this.pageSize = pageSize;
    }
}
